Ticks are plotted at censoring times that are also not event times
Adds tickmarks at the times when there are censored observations but no events
GeomKmticksgeom_kmticks(mapping = NULL, data = NULL, stat = "kmticks",
position = "identity", show.legend = NA, inherit.aes = TRUE,
na.rm = TRUE, ...)
The data to be displayed in this layer. There are three options:
If NULL, the default, the data is inherited from the plot
data as specified in the call to ggplot.
A data.frame, or other object, will override the plot
data. All objects will be fortified to produce a data frame. See
fortify for which variables will be created.
A function will be called with a single argument,
the plot data. The return value must be a data.frame., and
will be used as the layer data.
The statistical transformation to use on the data for this layer, as a string.
Position adjustment, either as a string, or the result of a call to a position adjustment function.
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.
FALSE never includes, and TRUE always includes.
If FALSE, overrides the default aesthetics,
rather than combining with them. This is most useful for helper functions
that define both data and aesthetics and shouldn't inherit behaviour from
the default plot specification, e.g. borders.
If FALSE, the default, missing values are removed with
a warning. If TRUE, missing values are silently removed.
other arguments passed on to layer. These are
often aesthetics, used to set an aesthetic to a fixed value, like
color = "red" or size = 3. They may also be parameters
to the paired geom/stat.
An object of class GeomKmticks (inherits from Geom, ggproto) of length 6.
geom_kmticks understands the following aesthetics (required aesthetics
are in bold):
The default stat for this geom is stat_kmticks see
that documentation for more options to control the underlying statistical transformation.
# NOT RUN {
library(ggplot2)
sex <- rbinom(250, 1, .5)
df <- data.frame(time = exp(rnorm(250, mean = sex)), status = rbinom(250, 1, .75), sex = sex)
ggplot(df, aes(time = time, status = status, color = factor(sex))) + geom_km() + geom_kmticks()
# }
Run the code above in your browser using DataLab